@@ -873,7 +873,7 @@ public class Project implements ResourceFactory {
             try {
                 setBasedir(".");
             } catch (final BuildException ex) {
-                ex.printStackTrace();
+                ex.printStackTrace(); //NOSONAR
             }
         }
         return baseDir;
@@ -1430,7 +1430,7 @@ public class Project implements ResourceFactory {
                             "Target '" + curtarget.getName()
                             + "' failed with message '"
                             + thrownException.getMessage() + "'.", MSG_ERR);
-                        thrownException.printStackTrace(System.err);
+                        thrownException.printStackTrace(System.err); //NOSONAR
                         if (buildException == null) {
                             buildException =
                                 new BuildException(thrownException);
@@ -1836,7 +1836,7 @@ public class Project implements ResourceFactory {
             if (st == null) {
                 tsort(root[i], targetTable, state, visiting, ret);
             } else if (st == VISITING) {
-                throw new RuntimeException("Unexpected node in visiting state: "
+                throw new BuildException("Unexpected node in visiting state: "
                     + root[i]);
             }
         }
@@ -1845,7 +1845,7 @@ public class Project implements ResourceFactory {
         for (int j = 0; j < root.length; j++) {
             buf.append((j == 0) ? " `" : ", `").append(root[j]).append('\'');
         }
-        buf.append(" is " + ret);
+        buf.append(" is ").append(ret);
         log(buf.toString(), MSG_VERBOSE);
 
         final Vector<Target> complete = (returnAll) ? ret : new Vector<Target>(ret);
@@ -1855,7 +1855,7 @@ public class Project implements ResourceFactory {
             if (st == null) {
                 tsort(curTarget, targetTable, state, visiting, complete);
             } else if (st == VISITING) {
-                throw new RuntimeException("Unexpected node in visiting state: "
+                throw new BuildException("Unexpected node in visiting state: "
                     + curTarget);
             }
         }
@@ -1941,7 +1941,7 @@ public class Project implements ResourceFactory {
         }
         final String p = visiting.pop();
         if (root != p) {
-            throw new RuntimeException("Unexpected internal error: expected to "
+            throw new BuildException("Unexpected internal error: expected to "
                 + "pop " + root + " but got " + p);
         }
         state.put(root, VISITED);
