@@ -1023,7 +1023,7 @@ public class JUnitTestRunner implements TestListener, JUnitTaskMirror.JUnitTestR
                     }
                 }
             } catch (final IOException e) {
-                e.printStackTrace();
+                e.printStackTrace(); //NOSONAR
             }
         } else {
             final JUnitTest t = new JUnitTest(args[0]);
@@ -1240,6 +1240,7 @@ public class JUnitTestRunner implements TestListener, JUnitTaskMirror.JUnitTestR
                     final String msg = t.getMessage();
                     final AssertionFailedError failure = msg != null
                         ? new AssertionFailedError(msg) : new AssertionFailedError();
+                    failure.initCause(t.getCause());
                     failure.setStackTrace(t.getStackTrace());
                     testListener.addFailure(test, failure);
                 } else {
