@@ -333,7 +333,7 @@ public class TarEntry implements TarConstants {
      * @return True if the entries are equal.
      */
     public boolean equals(TarEntry it) {
-        return getName().equals(it.getName());
+        return it != null && getName().equals(it.getName());
     }
 
     /**
@@ -706,8 +706,7 @@ public class TarEntry implements TarConstants {
      * @return true if this is a long name extension provided by GNU tar
      */
     public boolean isGNULongLinkEntry() {
-        return linkFlag == LF_GNUTYPE_LONGLINK
-            && name.equals(GNU_LONGLINK);
+        return linkFlag == LF_GNUTYPE_LONGLINK;
     }
 
     /**
@@ -716,8 +715,7 @@ public class TarEntry implements TarConstants {
      * @return true if this is a long name extension provided by GNU tar
      */
     public boolean isGNULongNameEntry() {
-        return linkFlag == LF_GNUTYPE_LONGNAME
-                           && name.equals(GNU_LONGLINK);
+        return linkFlag == LF_GNUTYPE_LONGNAME;
     }
 
     /**
@@ -848,7 +846,7 @@ public class TarEntry implements TarConstants {
                 writeEntryHeader(outbuf, TarUtils.FALLBACK_ENCODING, false);
             } catch (IOException ex2) {
                 // impossible
-                throw new RuntimeException(ex2);
+                throw new RuntimeException(ex2); //NOSONAR
             }
         }
     }
@@ -934,7 +932,7 @@ public class TarEntry implements TarConstants {
                 parseTarHeader(header, TarUtils.DEFAULT_ENCODING, true);
             } catch (IOException ex2) {
                 // not really possible
-                throw new RuntimeException(ex2);
+                throw new RuntimeException(ex2); //NOSONAR
             }
         }
     }
@@ -1097,7 +1095,8 @@ public class TarEntry implements TarConstants {
         try {
             buffer1 = expected.getBytes("ASCII");
         } catch (UnsupportedEncodingException e) {
-            throw new RuntimeException(e); // Should not happen
+            // Should not happen
+            throw new RuntimeException(e); //NOSONAR
         }
         return isEqual(buffer1, 0, buffer1.length, buffer, offset, length,
                        false);
