@@ -23,13 +23,19 @@ import static org.junit.Assert.assertTrue;
 import static org.apache.tools.ant.AntAssert.assertContains;
 import static org.junit.Assert.fail;
 
+import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.FileReader;
 import java.io.InputStream;
+import java.io.IOException;
 import java.net.URL;
+import java.security.Permission;
+import javax.xml.transform.TransformerFactory;
+import javax.xml.transform.TransformerFactoryConfigurationError;
 
 import org.apache.tools.ant.BuildFileRule;
 import org.apache.tools.ant.util.FileUtils;
+import org.junit.Assume;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
@@ -40,11 +46,11 @@ import org.junit.Test;
  *
  */
 public class JUnitReportTest {
-	
-	@Rule
-	public BuildFileRule buildRule = new BuildFileRule();
 
-	@Before
+    @Rule
+    public BuildFileRule buildRule = new BuildFileRule();
+
+    @Before
     public void setUp() {
         buildRule.configureProject("src/etc/testcases/taskdefs/optional/junitreport.xml");
     }
@@ -54,40 +60,61 @@ public class JUnitReportTest {
      * output is selected via the default.
      * Needs reports1 task from junitreport.xml.
      */
-	@Test
+    @Test
     public void testNoFileJUnitNoFrames() {
         buildRule.executeTarget("reports1");
         assertFalse("No file junit-noframes.html expected", (new File(System.getProperty("root"), "src/etc/testcases/taskdefs/optional/junitreport/test/html/junit-noframes.html").exists()));
-        
+
     }
 
     public void assertIndexCreated() {
-        if (!new File(buildRule.getProject().getProperty("output"), "html/index.html").exists()) {
-            fail("No file index file found");
+        try {
+            commonIndexFileAssertions();
+        } catch (IOException ex) {
+            throw new RuntimeException(ex);
         }
-
     }
 
+    private File commonIndexFileAssertions() throws IOException {
+        File reportFile = new File(buildRule.getOutputDir(), "html/index.html");
+        commonIndexFileAssertions(reportFile);
+        return reportFile;
+    }
+
+    private void commonIndexFileAssertions(File reportFile) throws IOException {
+        // tests one the file object
+        assertTrue("No index.html present. Not generated?", reportFile.exists() );
+        assertTrue("Cant read the report file.", reportFile.canRead() );
+        assertTrue("File shouldn't be empty.", reportFile.length() > 0 );
+        // conversion to URL via FileUtils like in XMLResultAggregator, not as suggested in the bug report
+        URL reportUrl = new URL( FileUtils.getFileUtils().toURI(reportFile.getAbsolutePath()) );
+        InputStream reportStream = reportUrl.openStream();
+        try {
+            assertTrue("This shouldn't be an empty stream.", reportStream.available() > 0);
+        } finally {
+            FileUtils.getFileUtils().close(reportStream);
+        }
+    }
 
     @Test
     public void testEmptyFile() throws Exception {
-    	buildRule.executeTarget("testEmptyFile");
+        buildRule.executeTarget("testEmptyFile");
         assertIndexCreated();
-    	assertContains("Required text not found in log", XMLResultAggregator.WARNING_EMPTY_FILE, buildRule.getLog());
+        assertContains("Required text not found in log", XMLResultAggregator.WARNING_EMPTY_FILE, buildRule.getLog());
     }
 
     @Test
     public void testIncompleteFile() throws Exception {
         buildRule.executeTarget("testIncompleteFile");
         assertIndexCreated();
-    	assertContains("Required text not found in log", XMLResultAggregator.WARNING_IS_POSSIBLY_CORRUPTED, buildRule.getLog());
+        assertContains("Required text not found in log", XMLResultAggregator.WARNING_IS_POSSIBLY_CORRUPTED, buildRule.getLog());
     }
-    
+
     @Test
     public void testWrongElement() throws Exception {
         buildRule.executeTarget("testWrongElement");
         assertIndexCreated();
-    	assertContains("Required text not found in log", XMLResultAggregator.WARNING_INVALID_ROOT_ELEMENT, buildRule.getLog());
+        assertContains("Required text not found in log", XMLResultAggregator.WARNING_INVALID_ROOT_ELEMENT, buildRule.getLog());
     }
 
     // Bugzilla Report 34963
@@ -111,44 +138,21 @@ public class JUnitReportTest {
     @Test
     public void testSpecialSignsInSrcPath() throws Exception {
         buildRule.executeTarget("testSpecialSignsInSrcPath");
-        File reportFile = new File(buildRule.getOutputDir(), "html/index.html");
-        // tests one the file object
-        assertTrue("No index.html present. Not generated?", reportFile.exists() );
-        assertTrue("Cant read the report file.", reportFile.canRead() );
-        assertTrue("File shouldn't be empty.", reportFile.length() > 0 );
-        // conversion to URL via FileUtils like in XMLResultAggregator, not as suggested in the bug report
-        URL reportUrl = new URL( FileUtils.getFileUtils().toURI(reportFile.getAbsolutePath()) );
-        InputStream reportStream = reportUrl.openStream();
-        assertTrue("This shouldn't be an empty stream.", reportStream.available() > 0);
+        commonIndexFileAssertions();
     }
 
     @Test
     public void testSpecialSignsInHtmlPath() throws Exception {
         buildRule.executeTarget("testSpecialSignsInHtmlPath");
         File reportFile = new File(buildRule.getOutputDir(), "html# $%\u00A7&-!report/index.html");
-        // tests one the file object
-        assertTrue("No index.html present. Not generated?", reportFile.exists() );
-        assertTrue("Cant read the report file.", reportFile.canRead() );
-        assertTrue("File shouldn't be empty.", reportFile.length() > 0 );
-        // conversion to URL via FileUtils like in XMLResultAggregator, not as suggested in the bug report
-        URL reportUrl = new URL( FileUtils.getFileUtils().toURI(reportFile.getAbsolutePath()) );
-        InputStream reportStream = reportUrl.openStream();
-        assertTrue("This shouldn't be an empty stream.", reportStream.available() > 0);
+        commonIndexFileAssertions(reportFile);
     }
 
     //Bugzilla Report 39708
     @Test
     public void testWithStyleFromDir() throws Exception {
         buildRule.executeTarget("testWithStyleFromDir");
-        File reportFile = new File(buildRule.getOutputDir(), "html/index.html");
-        // tests one the file object
-        assertTrue("No index.html present. Not generated?", reportFile.exists() );
-        assertTrue("Cant read the report file.", reportFile.canRead() );
-        assertTrue("File shouldn't be empty.", reportFile.length() > 0 );
-        // conversion to URL via FileUtils like in XMLResultAggregator, not as suggested in the bug report
-        URL reportUrl = new URL( FileUtils.getFileUtils().toURI(reportFile.getAbsolutePath()) );
-        InputStream reportStream = reportUrl.openStream();
-        assertTrue("This shouldn't be an empty stream.", reportStream.available() > 0);
+        commonIndexFileAssertions();
     }
 
     //Bugzilla Report 40021
@@ -156,56 +160,68 @@ public class JUnitReportTest {
     public void testNoFrames() throws Exception {
         buildRule.executeTarget("testNoFrames");
         File reportFile = new File(buildRule.getOutputDir(), "html/junit-noframes.html");
-        // tests one the file object
-        assertTrue("No junit-noframes.html present. Not generated?", reportFile.exists() );
-        assertTrue("Cant read the report file.", reportFile.canRead() );
-        assertTrue("File shouldn't be empty.", reportFile.length() > 0 );
-        // conversion to URL via FileUtils like in XMLResultAggregator, not as suggested in the bug report
-        URL reportUrl = new URL( FileUtils.getFileUtils().toURI(reportFile.getAbsolutePath()) );
-        InputStream reportStream = reportUrl.openStream();
-        assertTrue("This shouldn't be an empty stream.", reportStream.available() > 0);
+        commonIndexFileAssertions(reportFile);
     }
+
     //Bugzilla Report 39708
     @Test
     public void testWithStyleFromDirAndXslImport() throws Exception {
         buildRule.executeTarget("testWithStyleFromDirAndXslImport");
-        File reportFile = new File(buildRule.getOutputDir(), "html/index.html");
-        // tests one the file object
-        assertTrue("No index.html present. Not generated?", reportFile.exists() );
-        assertTrue("Cant read the report file.", reportFile.canRead() );
-        assertTrue("File shouldn't be empty.", reportFile.length() > 0 );
-        // conversion to URL via FileUtils like in XMLResultAggregator, not as suggested in the bug report
-        URL reportUrl = new URL( FileUtils.getFileUtils().toURI(reportFile.getAbsolutePath()) );
-        InputStream reportStream = reportUrl.openStream();
-        assertTrue("This shouldn't be an empty stream.", reportStream.available() > 0);
+        commonIndexFileAssertions();
     }
 
     @Test
     public void testWithStyleFromClasspath() throws Exception {
         buildRule.executeTarget("testWithStyleFromClasspath");
-        File reportFile = new File(buildRule.getOutputDir(), "html/index.html");
-        // tests one the file object
-        assertTrue("No index.html present. Not generated?", reportFile.exists() );
-        assertTrue("Cant read the report file.", reportFile.canRead() );
-        assertTrue("File shouldn't be empty.", reportFile.length() > 0 );
-        // conversion to URL via FileUtils like in XMLResultAggregator, not as suggested in the bug report
-        URL reportUrl = new URL( FileUtils.getFileUtils().toURI(reportFile.getAbsolutePath()) );
-        InputStream reportStream = reportUrl.openStream();
-        assertTrue("This shouldn't be an empty stream.", reportStream.available() > 0);
+        commonIndexFileAssertions();
     }
 
     @Test
     public void testWithParams() throws Exception {
-    	buildRule.executeTarget("testWithParams");
-    	assertContains("key1=value1,key2=value2", buildRule.getLog());
-        File reportFile = new File(buildRule.getOutputDir(), "html/index.html");
-        // tests one the file object
-        assertTrue("No index.html present. Not generated?", reportFile.exists() );
-        assertTrue("Cant read the report file.", reportFile.canRead() );
-        assertTrue("File shouldn't be empty.", reportFile.length() > 0 );
-        // conversion to URL via FileUtils like in XMLResultAggregator, not as suggested in the bug report
-        URL reportUrl = new URL( FileUtils.getFileUtils().toURI(reportFile.getAbsolutePath()) );
-        InputStream reportStream = reportUrl.openStream();
-        assertTrue("This shouldn't be an empty stream.", reportStream.available() > 0);
+        buildRule.executeTarget("testWithParams");
+        assertContains("key1=value1,key2=value2", buildRule.getLog());
+        commonIndexFileAssertions();
     }
+
+    @Test
+    public void testWithSecurityManagerAndXalanFactory() throws Exception {
+        try {
+            String factoryName = TransformerFactory.newInstance().getClass().getName();
+            Assume.assumeTrue("TraxFactory is " + factoryName + " and not Xalan",
+                              "org.apache.xalan.processor.TransformerFactoryImpl"
+                              .equals(factoryName));
+        } catch (TransformerFactoryConfigurationError exc) {
+            throw new RuntimeException(exc);
+        }
+        try {
+            System.setSecurityManager(new SecurityManager() {public void checkPermission(Permission perm) {}});
+            buildRule.executeTarget("testWithStyleFromClasspath");
+            commonIndexFileAssertions();
+        } finally {
+            System.setSecurityManager(null);
+        }
+    }
+
+    @Test
+    public void testWithSecurityManagerAndJDKFactory() throws Exception {
+        ClassLoader orig = Thread.currentThread().getContextClassLoader();
+        try {
+            Thread.currentThread().setContextClassLoader(new ClassLoader(ClassLoader.getSystemClassLoader().getParent()) {
+                public InputStream getResourceAsStream(String name) {
+                    if (name.startsWith("META-INF/services/")) {
+                        // work around JAXP #6723276 in JDK 6
+                        return new ByteArrayInputStream(new byte[0]);
+                    }
+                    return super.getResourceAsStream(name);
+                }
+            });
+            System.setSecurityManager(new SecurityManager() {public void checkPermission(Permission perm) {}});
+            buildRule.executeTarget("testWithStyleFromClasspath");
+            commonIndexFileAssertions();
+        } finally {
+            System.setSecurityManager(null);
+            Thread.currentThread().setContextClassLoader(orig);
+        }
+    }
+
 }
